/*
  SD card read/write

  This example shows how to read and write data to and from an SD card file
  The circuit:
   SD card attached to SPI bus as follows:
 ** MOSI - pin 11
 ** MISO - pin 12
 ** CLK - pin 13
 ** CS - pin 4 (for MKRZero SD: SDCARD_SS_PIN)

  created   Nov 2010
  by David A. Mellis
  modified 9 Apr 2012
  by Tom Igoe

  This example code is in the public domain.

Adapted to include an h file containing {r,g,b} values and write a new h file
containing only grayscale values {gray} where gray is the average of r, g, and b..

*/

#include <SPI.h>
#include <SD.h>

#define imageRows 16  // the size of the image that is going to be displayed.  Height normally 16.
#define imageCols 167  // Change this number depending on the width of your scrolling image.
#define moonRows 48
#define moonCols 48
#define batUpRows 16
#define batUpCols 19
#define batDownRows 16
#define batDownCols 19
#define witchRows 16
#define witchCols 19

const uint8_t hhw[imageRows][imageCols][3] PROGMEM = 
#include "Happy_Halloween_white_167x16.h"   // Happy Halloween written in white with black background
;
const uint8_t bu[batUpRows][batUpCols][3] PROGMEM = 
#include "bat_up_19x16.h"   // black bat with wings up, on white background
;
const uint8_t bd[batDownRows][batDownCols][3] PROGMEM = 
#include "bat_down_19x16.h"   // black bat with wings down, on white background
;
const uint8_t witch[witchRows][witchCols][3] PROGMEM = 
#include "flying_witch_19x16.h"   // black witch silhouette on white background
;
const uint8_t moon[moonRows][moonCols][3] PROGMEM = 
#include "full_moon_darker_48x48.h"   // full moon image on black background.
;

File myFile;

int col;
int row;
int avg;


void setup() {
  // Open serial communications and wait for port to open:
  Serial.begin(9600);
  while (!Serial) {
    ; // wait for serial port to connect. Needed for native USB port only
  }


  Serial.print("Initializing SD card...");

  if (!SD.begin()) {
    Serial.println("initialization failed!");
    while (1);
  }
  Serial.println("initialization done.");

  // open the file. note that only one file can be open at a time,
  // so you have to close this one before opening another.
  myFile = SD.open("HHg.h", FILE_WRITE);

  // if the file opened okay, write to it:
  if (myFile) {
    Serial.print("Writing...");
    myFile.print("{");
    for (row=0; row < imageRows; row++) {
      myFile.print("{");
      for (col=0; col < imageCols; col++) {
        avg = (int(pgm_read_byte_near(&hhw[row][col][0])) + int(pgm_read_byte_near(&hhw[row][col][1])) + int(pgm_read_byte_near(&hhw[row][col][2])))/3;
        myFile.print(avg);
        if (col < imageCols-1) {
          myFile.print(",");
        }
      }
      if (row < imageRows-1) {
        myFile.print("},");
      }
      else {
        myFile.println("}}");
      }
    }

    // close the file:
    myFile.close();
    Serial.println("done.");
  } else {
    // if the file didn't open, print an error:
    Serial.println("error opening hhg");
  }

  myFile = SD.open("moong.h", FILE_WRITE);

  // if the file opened okay, write to it:
  if (myFile) {
    Serial.print("Writing...");
    myFile.print("{");
    for (row=0; row < moonRows; row++) {
      myFile.print("{");
      for (col=0; col < moonCols; col++) {
        avg = (int(pgm_read_byte_near(&moon[row][col][0])) + int(pgm_read_byte_near(&moon[row][col][1])) + int(pgm_read_byte_near(&moon[row][col][2])))/3;
        myFile.print(avg);
        if (col < moonCols-1) {
          myFile.print(",");
        }
      }
      if (row < moonRows-1) {
        myFile.print("},");
      }
      else {
        myFile.println("}}");
      }
    }

    // close the file:
    myFile.close();
    Serial.println("done.");
  } else {
    // if the file didn't open, print an error:
    Serial.println("error opening moon");
  }

  myFile = SD.open("batupg.h", FILE_WRITE);

  // if the file opened okay, write to it:
  if (myFile) {
    Serial.print("Writing...");
    myFile.print("{");
    for (row=0; row < batUpRows; row++) {
      myFile.print("{");
      for (col=0; col < batUpCols; col++) {
        avg = (int(pgm_read_byte_near(&bu[row][col][0])) + int(pgm_read_byte_near(&bu[row][col][1])) + int(pgm_read_byte_near(&bu[row][col][2])))/3;
        myFile.print(avg);
        if (col < batUpCols-1) {
          myFile.print(",");
        }
      }
      if (row < batUpRows-1) {
        myFile.print("},");
      }
      else {
        myFile.println("}}");
      }
    }

    // close the file:
    myFile.close();
    Serial.println("done.");
  } else {
    // if the file didn't open, print an error:
    Serial.println("error opening bu");
  }

  myFile = SD.open("batdowng.h", FILE_WRITE);

  // if the file opened okay, write to it:
  if (myFile) {
    Serial.print("Writing...");
    myFile.print("{");
    for (row=0; row < batDownRows; row++) {
      myFile.print("{");
      for (col=0; col < batDownCols; col++) {
        avg = (int(pgm_read_byte_near(&bd[row][col][0])) + int(pgm_read_byte_near(&bd[row][col][1])) + int(pgm_read_byte_near(&bd[row][col][2])))/3;
        myFile.print(avg);
        if (col < batDownCols-1) {
          myFile.print(",");
        }
      }
      if (row < batDownRows-1) {
        myFile.print("},");
      }
      else {
        myFile.println("}}");
      }
    }

    // close the file:
    myFile.close();
    Serial.println("done.");
  } else {
    // if the file didn't open, print an error:
    Serial.println("error opening bd");
  }

  myFile = SD.open("witchg.h", FILE_WRITE);

  // if the file opened okay, write to it:
  if (myFile) {
    Serial.print("Writing...");
    myFile.print("{");
    for (row=0; row < witchRows; row++) {
      myFile.print("{");
      for (col=0; col < witchCols; col++) {
        avg = (int(pgm_read_byte_near(&witch[row][col][0])) + int(pgm_read_byte_near(&witch[row][col][1])) + int(pgm_read_byte_near(&witch[row][col][2])))/3;
        myFile.print(avg);
        if (col < witchCols-1) {
          myFile.print(",");
        }
      }
      if (row < witchRows-1) {
        myFile.print("},");
      }
      else {
        myFile.println("}}");
      }
    }

    // close the file:
    myFile.close();
    Serial.println("done.");
  } else {
    // if the file didn't open, print an error:
    Serial.println("error opening witch");
  }

}

void loop() {
  // nothing happens after setup
}
